@@ -162,57 +162,48 @@ FunctionInfo::FunctionInfo(const char *name, const char *type,
 {
       DEBUGPROFMSG("FunctionInfo::FunctionInfo: MyProfileGroup_ = " << MyProfileGroup_ 
         << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
-      if (ProfileGroup & RtsLayer::TheProfileMask()) {
 
-        Name = name;
-  	Type = type;
+      Name = name;
+      Type = type;
 
-	FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
-      }
+      FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
 
 //////////////////////////////////////////////////////////////////////
 
-FunctionInfo::FunctionInfo(const char *name, string& type, 
+FunctionInfo::FunctionInfo(const char *name, const string& type, 
 	TauGroup_t ProfileGroup , const char *ProfileGroupName, bool InitData,
 	int tid)
 {
-      if (ProfileGroup & RtsLayer::TheProfileMask()) {
+      Name = name;
+      Type = type;
 
-        Name = name;
-  	Type = type;
-
-	FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
-      }
+      FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
 
 //////////////////////////////////////////////////////////////////////
 
-FunctionInfo::FunctionInfo(string& name, const char * type, 
+FunctionInfo::FunctionInfo(const string& name, const char * type, 
 	TauGroup_t ProfileGroup , const char *ProfileGroupName, bool InitData,
 	int tid)
 {
-      if (ProfileGroup & RtsLayer::TheProfileMask()) {
+      Name = name;
+      Type = type;
 
-        Name = name;
-  	Type = type;
-
-	FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
-      }
+      FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
 
 //////////////////////////////////////////////////////////////////////
 
-FunctionInfo::FunctionInfo(string& name, string& type, 
+FunctionInfo::FunctionInfo(const string& name, const string& type, 
 	TauGroup_t ProfileGroup , const char *ProfileGroupName, bool InitData,
 	int tid)
 {
-      if (ProfileGroup & RtsLayer::TheProfileMask()) {
 
-        Name = name;
-  	Type = type;
-	FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
-      }
+      Name = name;
+      Type = type;
+ 
+      FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
 
 //////////////////////////////////////////////////////////////////////
@@ -258,7 +249,7 @@ long FunctionInfo::GetFunctionId(void)
 //////////////////////////////////////////////////////////////////////
 
 /***************************************************************************
- * $RCSfile: FunctionInfo.cpp,v $   $Author: bertie $
- * $Revision: 1.21 $   $Date: 1999/10/27 21:16:35 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.21 1999/10/27 21:16:35 bertie Exp $ 
+ * $RCSfile: FunctionInfo.cpp,v $   $Author: sameer $
+ * $Revision: 1.25 $   $Date: 2001/10/03 21:04:24 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.25 2001/10/03 21:04:24 sameer Exp $ 
  ***************************************************************************/
